@@ -338,16 +338,16 @@ gupnp_service_proxy_class_init (GUPnPServiceProxyClass *klass)
  * gupnp_service_proxy_send_action
  * @proxy: A #GUPnPServiceProxy
  * @action: An action
- * @error: The location where to store any error, or NULL
+ * @error: The location where to store any error, or %NULL
  * @Varargs: tuples of in parameter name, in paramater type, and in parameter
- * value, followed by NULL, and then tuples of out paramater name,
- * out parameter type, and out parameter value location, terminated with NULL
+ * value, followed by %NULL, and then tuples of out paramater name,
+ * out parameter type, and out parameter value location, terminated with %NULL
  *
  * Sends action @action with parameters @Varargs to the service exposed by
  * @proxy synchronously. If an error occurred, @error will be set. In case of
  * a UPnPError the error code will be the same in @error.
  *
- * Return value: TRUE if sending the action was succesful.
+ * Return value: %TRUE if sending the action was succesful.
  **/
 gboolean
 gupnp_service_proxy_send_action (GUPnPServiceProxy *proxy,
@@ -380,15 +380,15 @@ stop_main_loop (GUPnPServiceProxy       *proxy,
  * gupnp_service_proxy_send_action_valist
  * @proxy: A #GUPnPServiceProxy
  * @action: An action
- * @error: The location where to store any error, or NULL
+ * @error: The location where to store any error, or %NULL
  * @var_args: va_list of tuples of in parameter name, in paramater type, and in
- * parameter value, followed by NULL, and then tuples of out paramater name,
+ * parameter value, followed by %NULL, and then tuples of out paramater name,
  * out parameter type, and out parameter value location
  *
  * See gupnp_service_proxy_send_action(); this version takes a va_list for
  * use by language bindings.
  *
- * Return value: TRUE if sending the action was succesful.
+ * Return value: %TRUE if sending the action was succesful.
  **/
 gboolean
 gupnp_service_proxy_send_action_valist (GUPnPServiceProxy *proxy,
@@ -433,7 +433,7 @@ gupnp_service_proxy_send_action_valist (GUPnPServiceProxy *proxy,
  * gupnp_service_proxy_send_action_hash
  * @proxy: A #GUPnPServiceProxy
  * @action: An action
- * @error: The location where to store any error, or NULL
+ * @error: The location where to store any error, or %NULL
  * @in_hash: A #GHashTable of in parameter name and #GValue pairs
  * @out_hash: A #GHashTable of out parameter name and initialized
  * #GValue pairs
@@ -441,7 +441,7 @@ gupnp_service_proxy_send_action_valist (GUPnPServiceProxy *proxy,
  * See gupnp_service_proxy_send_action(); this version takes a pair of
  * #GHashTable<!-- -->s for runtime determined parameter lists.
  *
- * Return value: TRUE if sending the action was succesful.
+ * Return value: %TRUE if sending the action was succesful.
  **/
 gboolean
 gupnp_service_proxy_send_action_hash (GUPnPServiceProxy *proxy,
@@ -496,7 +496,7 @@ gupnp_service_proxy_send_action_hash (GUPnPServiceProxy *proxy,
  * or failed
  * @user_data: User data for @callback
  * @Varargs: tuples of in parameter name, in paramater type, and in parameter
- * value, terminated with NULL
+ * value, terminated with %NULL
  *
  * Sends action @action with parameters @Varargs to the service exposed by
  * @proxy asynchronously, calling @callback on completion. From @callback, call
@@ -536,7 +536,7 @@ begin_action_msg (GUPnPServiceProxy              *proxy,
                   gpointer                        user_data)
 {
         GUPnPServiceProxyAction *ret;
-        char *control_url, *lang, *full_action;
+        char *control_url, *full_action;
         const char *service_type;
 
         /* Create action structure */
@@ -583,26 +583,16 @@ begin_action_msg (GUPnPServiceProxy              *proxy,
                 return ret;
         }
 
-        /* Specify language */
-        lang = accept_language_get_header ();
-        if (lang) {
-                soup_message_headers_append
-                        (SOUP_MESSAGE (ret->msg)->request_headers,
-                         "Accept-Language",
-                         lang);
-
-                g_free (lang);
-        }
-
         /* Specify action */
         full_action = g_strdup_printf ("\"%s#%s\"", service_type, action);
-        soup_message_headers_append (SOUP_MESSAGE (ret->msg)->request_headers,
+        soup_message_headers_append (ret->msg->request_headers,
 				     "SOAPAction",
                                      full_action);
         g_free (full_action);
 
-        /* Specify user agent */
-        message_set_user_agent (SOUP_MESSAGE (ret->msg));
+        /* Specify user agent and language */
+        http_request_set_user_agent (ret->msg);
+        http_request_set_accept_language (ret->msg);
 
         /* Set up envelope */
         ret->msg_str = xml_util_new_string ();
@@ -703,7 +693,7 @@ finish_action_msg (GUPnPServiceProxyAction *action,
         session = _gupnp_context_get_session (context);
 
         soup_session_queue_message (session,
-                                    SOUP_MESSAGE (action->msg),
+                                    action->msg,
                                     (SoupSessionCallback) action_got_response,
                                     action);
 }
@@ -852,16 +842,16 @@ gupnp_service_proxy_begin_action_hash
  * gupnp_service_proxy_end_action
  * @proxy: A #GUPnPServiceProxy
  * @action: A #GUPnPServiceProxyAction handle
- * @error: The location where to store any error, or NULL
+ * @error: The location where to store any error, or %NULL
  * @Varargs: tuples of out parameter name, out paramater type, and out parameter
- * value location, terminated with NULL. The out parameter values should be
+ * value location, terminated with %NULL. The out parameter values should be
  * freed after use
  *
  * Retrieves the result of @action. The out parameters in @Varargs will be
  * filled in, and if an error occurred, @error will be set. In case of
  * a UPnPError the error code will be the same in @error.
  *
- * Return value: TRUE on success.
+ * Return value: %TRUE on success.
  **/
 gboolean
 gupnp_service_proxy_end_action (GUPnPServiceProxy       *proxy,
@@ -890,19 +880,16 @@ check_action_response (GUPnPServiceProxy       *proxy,
                        xmlNode                **params,
                        GError                 **error)
 {
-        SoupMessage *soup_msg;
         xmlDoc *response;
         int code;
 
-        soup_msg = SOUP_MESSAGE (action->msg);
-
         /* Check for errors */
-        switch (soup_msg->status_code) {
+        switch (action->msg->status_code) {
         case SOUP_STATUS_OK:
         case SOUP_STATUS_INTERNAL_SERVER_ERROR:
                 break;
         default:
-                set_server_error (error, soup_msg);
+                set_server_error (error, action->msg);
 
                 return NULL;
         }
@@ -912,7 +899,7 @@ check_action_response (GUPnPServiceProxy       *proxy,
                                    action->msg->response_body->length);
 
 	if (!response) {
-                if (soup_msg->status_code == SOUP_STATUS_OK) {
+                if (action->msg->status_code == SOUP_STATUS_OK) {
                         g_set_error (error,
                                      GUPNP_SERVER_ERROR,
                                      GUPNP_SERVER_ERROR_INVALID_RESPONSE,
@@ -922,7 +909,7 @@ check_action_response (GUPnPServiceProxy       *proxy,
                                     (error,
                                      GUPNP_SERVER_ERROR,
                                      GUPNP_SERVER_ERROR_INTERNAL_SERVER_ERROR,
-                                     soup_msg->reason_phrase);
+                                     action->msg->reason_phrase);
                 }
 
                 return NULL;
@@ -959,7 +946,7 @@ check_action_response (GUPnPServiceProxy       *proxy,
         }
 
         /* Check whether we have a Fault */
-        if (soup_msg->status_code == SOUP_STATUS_INTERNAL_SERVER_ERROR) {
+        if (action->msg->status_code == SOUP_STATUS_INTERNAL_SERVER_ERROR) {
                 xmlNode *param;
                 char *desc;
 
@@ -997,7 +984,7 @@ check_action_response (GUPnPServiceProxy       *proxy,
                 desc = xml_util_get_child_element_content_glib
                                         (param, "errorDescription");
                 if (desc == NULL)
-                        desc = g_strdup (soup_msg->reason_phrase);
+                        desc = g_strdup (action->msg->reason_phrase);
 
                 set_error_literal (error,
                                    GUPNP_CONTROL_ERROR,
@@ -1041,7 +1028,7 @@ read_out_parameter (const char *arg_name,
  * gupnp_service_proxy_end_action_valist
  * @proxy: A #GUPnPServiceProxy
  * @action: A #GUPnPServiceProxyAction handle
- * @error: The location where to store any error, or NULL
+ * @error: The location where to store any error, or %NULL
  * @var_args: A va_list of tuples of out parameter name, out paramater type,
  * and out parameter value location. The out parameter values should be
  * freed after use
@@ -1049,7 +1036,7 @@ read_out_parameter (const char *arg_name,
  * See gupnp_service_proxy_end_action(); this version takes a va_list for
  * use by language bindings.
  *
- * Return value: TRUE on success.
+ * Return value: %TRUE on success.
  **/
 gboolean
 gupnp_service_proxy_end_action_valist (GUPnPServiceProxy       *proxy,
@@ -1122,13 +1109,13 @@ gupnp_service_proxy_end_action_valist (GUPnPServiceProxy       *proxy,
  * gupnp_service_proxy_end_action_hash
  * @proxy: A #GUPnPServiceProxy
  * @action: A #GUPnPServiceProxyAction handle
- * @error: The location where to store any error, or NULL
+ * @error: The location where to store any error, or %NULL
  * @hash: A #GHashTable of out parameter name and initialised #GValue pairs
  *
  * See gupnp_service_proxy_end_action(); this version takes a #GHashTable
  * for runtime generated parameter lists.
  *
- * Return value: TRUE on success.
+ * Return value: %TRUE on success.
  **/
 gboolean
 gupnp_service_proxy_end_action_hash (GUPnPServiceProxy       *proxy,
@@ -1196,7 +1183,7 @@ gupnp_service_proxy_cancel_action (GUPnPServiceProxy       *proxy,
                 session = _gupnp_context_get_session (context);
 
                 soup_session_cancel_message (session,
-                                             SOUP_MESSAGE (action->msg),
+                                             action->msg,
                                              SOUP_STATUS_CANCELLED);
         }
 
@@ -1217,7 +1204,7 @@ gupnp_service_proxy_cancel_action (GUPnPServiceProxy       *proxy,
  * Sets up @callback to be called whenever a change notification for
  * @variable is recieved.
  *
- * Return value: TRUE on success.
+ * Return value: %TRUE on success.
  **/
 gboolean
 gupnp_service_proxy_add_notify (GUPnPServiceProxy              *proxy,
@@ -1279,7 +1266,7 @@ gupnp_service_proxy_add_notify (GUPnPServiceProxy              *proxy,
  *
  * Cancels the variable change notification for @callback and @user_data.
  *
- * Return value: TRUE on success.
+ * Return value: %TRUE on success.
  **/
 gboolean
 gupnp_service_proxy_remove_notify (GUPnPServiceProxy              *proxy,
@@ -1884,7 +1871,7 @@ unsubscribe (GUPnPServiceProxy *proxy)
 /**
  * gupnp_service_proxy_set_subscribed
  * @proxy: A #GUPnPServiceProxy
- * @subscribed: TRUE to subscribe to this service
+ * @subscribed: %TRUE to subscribe to this service
  *
  * (Un)subscribes to this service.
  *
